asr.setup.defects
=================

.. automodule:: asr.setup.defects

   
   
   .. rubric:: Functions

   
   .. autofunction:: collect_data
   .. autofunction:: create_folder_structure
   .. autofunction:: setup_defects
   .. autofunction:: setup_supercell
   
   

   
   
   

   
   
   